@@ -259,15 +259,11 @@ class AppDetails(Gtk.ScrolledWindow):
 
         self.show_row_spinner(False)
 
-        self.desc_row.set_visible(len(self.description.get_text()) > 0)
-
         if load_completed_callback:
             load_completed_callback()
 
     @_async
     def load(self, load_completed_callback: Optional[Callable] = None):
-        self.show_row_spinner(True)
-
         if self.command_line_arguments_row:
             self.command_line_arguments_row.remove_css_class('error')
 
@@ -289,6 +285,7 @@ class AppDetails(Gtk.ScrolledWindow):
         )
 
     def before_load(self):
+        self.show_row_spinner(True)
         self.title.set_visible(False)
         self.app_subtitle.set_visible(False)
         self.description.set_visible(False)
@@ -307,10 +304,6 @@ class AppDetails(Gtk.ScrolledWindow):
     @_async
     def install_file(self, el: AppImageListElement):
         self.provider.install_file(el)
-        # try:
-        # except Exception as e:
-        #     logging.error(str(e))
-
         self.update_installation_status()
 
         self.complete_load(
@@ -647,7 +640,6 @@ class AppDetails(Gtk.ScrolledWindow):
 
             if selected_model:
                 update_url = app_conf.get('update_url', '')
-                manager_config = app_conf.get('update_manager_config', {})
                 self.update_manager = selected_model(url=update_url, embedded=False, el=self.app_list_element)
             else:
                 if self.app_list_element:
@@ -661,7 +653,6 @@ class AppDetails(Gtk.ScrolledWindow):
 
         if self.update_manager:
             rows = self.update_manager.load_form_rows(
-                update_url=self.update_manager.url,
                 embedded=self.update_manager.embedded
             )
 
@@ -716,7 +707,7 @@ class AppDetails(Gtk.ScrolledWindow):
             self.on_app_update_url_reset()
             return
 
-        text = self.update_manager.get_form_url()
+        text = self.update_manager.get_url_from_form()
 
         if not text:
             self.on_app_update_url_error()
@@ -733,11 +724,12 @@ class AppDetails(Gtk.ScrolledWindow):
             return
 
         self.update_manager.set_url(text)
+        self.update_manager.update_config_from_form()
 
         if not self.update_manager.embedded:
             app_conf['update_url'] = self.update_manager.url
             app_conf['update_url_manager'] = self.update_manager.name
-            app_conf['update_manager_config'] = self.update_manager.get_form_config()
+            app_conf['update_manager_config'] = self.update_manager.config
             save_config_for_app(app_conf)
 
         self.on_app_update_url_success()
