@@ -14,6 +14,7 @@ class UpdateManager(ABC):
     url = ''
     label = ''
     embedded = False
+    config = {}
     el: Optional[AppImageListElement] = None
     system_arch = platform.machine()
     is_x86 = re.compile(r'(\-|\_|\.)x86(\-|\_|\.)')
@@ -21,9 +22,9 @@ class UpdateManager(ABC):
 
     @abstractmethod
     def __init__(self, url: str, embedded: str|Literal[False]=False, el=None) -> None:
-        self.url = url
         self.el = el
         self.download_folder = os.path.join(TMP_DIR, 'downloads')
+        self.set_url(url)
 
     def cleanup(self):
         pass
@@ -41,7 +42,7 @@ class UpdateManager(ABC):
         pass
 
     @abstractmethod
-    def load_form_rows(self, update_url: str, embedded: bool) -> list:
+    def load_form_rows(self, embedded: bool) -> list:
         pass
 
     @staticmethod
@@ -50,12 +51,24 @@ class UpdateManager(ABC):
         pass
 
     @abstractmethod
-    def get_form_url(self) -> str:
+    def get_url_from_form(self) -> str:
         pass
 
-    def get_form_config(self) -> dict:
-        return {}
+    @abstractmethod
+    def get_url_from_params(self, **kwargs) -> str:
+        pass
+
+    def update_config_from_form(self):
+        pass
 
     @abstractmethod
     def set_url(self, url: str):
         self.url = url
+
+    def get_saved_config(self):
+        config = {}
+
+        if self.el:
+            config = self.el.get_config().get('update_manager_config', {})
+
+        return config
